<?php

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource\Manager;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;
use \Exception as Exception;
use Zeedhi\Framework\Util\Functions;

class CadChefe extends CrudWithParameterBag {
    const dataSourceSelectChefe = 'select_chefe';
    const dataSourceSelectChefeFilial = 'select_chefe_filial';
    protected $parameterBagColumns = ['NRORG'];

    public function __construct(ParameterBag $parameterBag, Manager $dataSourceManager, Services\CadChefeService $cadChefeService, Utilities\Util $util, $environment, Services\FileUploaderService $fileUploaderService) {
        $this->parameterBag = $parameterBag;
        $this->dataSourceManager = $dataSourceManager;
        $this->cadChefeService = $cadChefeService;
        $this->fileUploaderService = $fileUploaderService;
        $this->util = $util;
        $this->environment = $environment;
    }
    
    public function findChefe(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceSelectChefe;
        $this->parameterBagColumns = array('NRORG');
        
        parent::find($request, $response);
    }
            
    public function saveChefe(DTO\Request\Row $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceSelectChefe;
        $rows = $request->getRow();
        
        try {
            if(!isset($rows['IMGCHEFE']) || $rows['IMGCHEFE'] == '') {
    	        $rows['IMGCHEFE'] = null;
    	    } else {
    	        if(isset($rows['IMGCHEFE'][0]['name'])) {
	                $rows['NMARQUIVO'] = $rows['IMGCHEFE'][0]['name'];
        	    }
        	    
        	    if(isset($rows['IMGCHEFE'][0]['path'])) {
                    if(Functions::arrayKeyExists('IMGCHEFE', $rows)) {
                        $this->fileUploaderService->setImageForSave($rows, 'IMGCHEFE', 'IMGCHEFE');
                    }
                } else {
                    $this->fileUploaderService->setImageForSave($rows, 'IMGCHEFE', 'IMGCHEFE');
                }
    	    }
    	    
    	    if($rows['is_new']) {
                $this->cadChefeService->saveChefe($rows);
    	    } else {
    	        $this->cadChefeService->updateChefe($rows);
    	    }
        } catch (Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteChefe(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $params = $this->util->getParamsAsArray($request);
            
            $this->cadChefeService->deleteChefeCascade($params[0]);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function findFilial(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceSelectChefeFilial;
        $this->parameterBagColumns = array('NRORG','CDCHEFE');
        
        parent::find($request, $response);
    }
    
    public function saveFilial(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            foreach($request->getDataSet()->getRows() as $row) {
                $arrayCodigoFilial = $row['CDFILIAL'];
                
                foreach($arrayCodigoFilial as $cdfilial) {
                    $row['CDFILIAL'] = $cdfilial;
                    $this->cadChefeService->saveFilial($row);
                }
            }
            
            $response->addNotification(new Notification("Dados inseridos com sucesso!", Notification::TYPE_SUCCESS));
        } catch (Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteFilial(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $row = $request->getDataSet()->getRows()[0];
            
            $this->cadChefeService->deleteFilial($row);
        } catch(\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
}