<?php

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\MAN\Services;

class Relatorio {
    protected $relatorioService;

    public function __construct (Services\ReportService $reportService, Services\Relatorio $relatorioService) {
        $this->reportService = $reportService;
        $this->relatorioService = $relatorioService;
    }

    public function geraRelatorio(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        if($row['REPORT_NAME'] == 'lmc'){
            $parameterMapping = array(
                    "CDFILIAL" => "CDFILIAL",
                    "CDPRODUTO" => "CDPRODUTO",
                    "DATA" => "DATA",
                    "DATES" => "DATES",
                    "NRORG" => "NRORG",
                    "REPEATER" => "REPEATER"
                );


            try{
                $row['REPEATER'] = count($row['DATES']);
                $row['DATES'] = implode(',', $row['DATES']);
                $row['DATA'] = 1;
                $dadosParaRelatorio = $this->relatorioService->buildParametersByRelatorio($row, $parameterMapping);
                $reportName = $dadosParaRelatorio['ReportName'];
                $parametersRow = $dadosParaRelatorio['ParametersRow'];
                $birtURL = $this->reportService->createRemoteReport('BIRT', $reportName, $parametersRow, true);
                $response->addDataset(new DataSet('URL',array($birtURL)));
            } catch (\Exception $e) {
                $response->setError(new Error($e->getMessage() , 500));
            }

        } else if($row['REPORT_NAME'] == 'movcaixa') {
            $parameterMapping = array(
                    "DATA" => "DATA",
                    "CDFILIAL" => "CDFILIAL",
                    "NRORG" => "NRORG",
                    "CDTABEPREC" => "CDTABEPREC",
                    "DTINIVGPREC" => "DTINIVGPREC",
                    "CDCAIXA" => "CDCAIXA",
                    "NMOPERADOR" => "NMOPERADOR",
                    "CDLOJA" => "CDLOJA"
                );


            try{
                $dadosTabelaPreco = $this->relatorioService->getTabelaPreco($row);
                $row['CDTABEPREC'] = $dadosTabelaPreco['CDTABPREC'];
                $row['DTINIVGPREC'] = $dadosTabelaPreco['DTINIVGPREC'];
                $dadosParaRelatorio = $this->relatorioService->buildParametersByRelatorio($row, $parameterMapping);
                $reportName = $dadosParaRelatorio['ReportName'];
                $parametersRow = $dadosParaRelatorio['ParametersRow'];
                $birtURL = $this->reportService->createRemoteReport('BIRT', $reportName, $parametersRow, true);
                $response->addDataset(new DataSet('URL',array($birtURL)));
            } catch (\Exception $e) {
                $response->setError(new Error($e->getMessage() , 500));
            }
        }
        else {
            $response->setError(new Error('Erro ao encontrar o relatório', 500));
            $chamaRelatorio = false;
        }
    }
}