<?php

namespace Teknisa\MAN\Services;

use Teknisa\MAN\Utilities;
use Teknisa\MAN\Factories;
use Teknisa\MAN\Services\NovoCodigo;
use Teknisa\Libs\Util\Environment;


class CupomDescontoService {
	protected $entityManager;
	protected $util;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager, Utilities\Util $util)  {
		$this->entityManager = $entityManager;
		$this->util = $util;
	}

	public function saveMultiCupons($params){
        return $this->entityManager->getConnection()->executeQuery(self::INSERT_MULTI_CUPONS, $params);
    }

	public function saveUnidadeParticipante($params){
        return $this->entityManager->getConnection()->executeQuery(self::INSERT_UNIDADE_PARTICIPANTE, $params);
    }

	public function saveProdutosParticipanteIntervalo($params){
        return $this->entityManager->getConnection()->executeQuery(self::INSERT_PRODUTOS_PARTICIPANTE_INTERVALO, $params);
    }

	public function saveProdutosParticipanteNivel($params){
        return $this->entityManager->getConnection()->executeQuery(self::INSERT_PRODUTOS_PARTICIPANTE_NIVEL, $params);
    }

	public function saveProdutosParticipanteLista($params){
        return $this->entityManager->getConnection()->executeQuery(self::INSERT_PRODUTOS_PARTICIPANTE_LISTA, $params);
    }

    public function findProdutosRegistrados($CDPRODUTO,$CDCUPOMDESCFOS, $NRORG){
    	$params = array(
    		':CDPRODUTO'  => $CDPRODUTO,
			':CDCUPOMDESCFOS'  => $CDCUPOMDESCFOS,
			':NRORG'            => $NRORG
		);
    	 return $this->entityManager->getConnection()->fetchAll(self::FindProduto, $params);
    }

    public function findProdutosRegistradosNivel($PRODNIV,$CDCUPOMDESCFOS, $NRORG){
    	$params = array(
    		':PRODNIV'  => $PRODNIV,
			':CDCUPOMDESCFOS'  => $CDCUPOMDESCFOS,
			':NRORG'            => $NRORG
		);
    	 return $this->entityManager->getConnection()->fetchAll(self::FindNivel, $params);
    }

    public function findProdutosRegistradosIntervalo($CDARVPRODI, $CDARVPRODF, $CDCUPOMDESCFOS, $NRORG){
    	$params = array(
    		':CDARVPRODI'  => $CDARVPRODI,
    		':CDARVPRODF'  => $CDARVPRODF,
			':CDCUPOMDESCFOS'  => $CDCUPOMDESCFOS,
			':NRORG'            => $NRORG
		);
    	 return $this->entityManager->getConnection()->fetchAll(self::FindIntervalo, $params);
    }

	public function validRandomCode($code) {
		$params = array(':CODE' => $code);
		$result = $this->entityManager->getConnection()->fetchAll(self::GET_CODE_TO_VALID, $params);
		return (empty($result) ? $code : false);
	}

	const GET_CODE_TO_VALID = "
		SELECT CDCUPOMDESCFOS
		  FROM CUPOMDESCFOS
		  WHERE CDCUPOMDESCFOS = :CODE
	";

	const INSERT_MULTI_CUPONS = "
		INSERT INTO CUPOMDESCFOS
			(CDCUPOMDESCFOS, DSCUPOMDESCFOS, IDTIPODESC, VRDESCCUPOM, DTINIVIGENCIA, DTFIMVIGENCIA, IDUSOUNICO, NRORG)
			VALUES
			(:CDCUPOMDESCFOS, :DSCUPOMDESCFOS, :IDTIPODESC, :VRDESCCUPOM, :DTINIVIGENCIA, :DTFIMVIGENCIA, :IDUSOUNICO, :NRORG)
	";

	const INSERT_UNIDADE_PARTICIPANTE = "
		INSERT INTO FILIALCUPOMDESC
			(CDFILIAL, CDCUPOMDESCFOS, NRORG, DTULTATU, DTINCLUSAO)
			VALUES
			(:CDFILIAL, :CDCUPOMDESCFOS, :NRORG, SYSDATE, SYSDATE)
	";

	const INSERT_PRODUTOS_PARTICIPANTE_INTERVALO = "
		INSERT INTO PRODCUPOMDESC
			(CDPRODUTO, CDCUPOMDESCFOS, NRORG, DTULTATU, DTINCLUSAO)
		SELECT CDPRODUTO, :CDCUPOMDESCFOS, :NRORG, SYSDATE, SYSDATE
                FROM PRODUTO
            WHERE CDARVPROD BETWEEN :CDARVPRODI AND :CDARVPRODF
	";


	const INSERT_PRODUTOS_PARTICIPANTE_NIVEL = "
		INSERT INTO PRODCUPOMDESC
			(CDPRODUTO, CDCUPOMDESCFOS, NRORG, DTULTATU, DTINCLUSAO)
		SELECT CDPRODUTO, :CDCUPOMDESCFOS, :NRORG, SYSDATE, SYSDATE
                FROM PRODUTO
            WHERE CDARVPROD LIKE :PRODNIV||'%'
	";

	const INSERT_PRODUTOS_PARTICIPANTE_LISTA = "
		INSERT INTO PRODCUPOMDESC
			(CDPRODUTO, CDCUPOMDESCFOS, NRORG, DTULTATU, DTINCLUSAO)
		SELECT CDPRODUTO, :CDCUPOMDESCFOS, :NRORG, SYSDATE, SYSDATE
                FROM PRODUTO
            WHERE CDPRODUTO = :CDPRODLIST
	";

	const FindProduto = "
	SELECT PC.CDCUPOMDESCFOS, PC.CDPRODUTO, PC.NRORG, P.NMPRODUTO, P.CDARVPROD
	FROM PRODCUPOMDESC PC JOIN PRODUTO P ON PC.CDPRODUTO = P.CDPRODUTO AND PC.NRORG = P.NRORG
	WHERE PC.CDCUPOMDESCFOS = :CDCUPOMDESCFOS AND PC.NRORG = :NRORG AND P.CDPRODUTO = :CDPRODUTO ORDER BY P.CDARVPROD
	";

	const FindNivel = "
		SELECT P.CDPRODUTO, PC.CDCUPOMDESCFOS, P.NRORG
              FROM PRODCUPOMDESC PC JOIN PRODUTO P ON PC.CDPRODUTO = P.CDPRODUTO AND PC.NRORG = P.NRORG
            WHERE PC.CDCUPOMDESCFOS = :CDCUPOMDESCFOS AND PC.NRORG = :NRORG AND P.CDARVPROD LIKE :PRODNIV||'%' ORDER BY P.CDARVPROD
	";


	const FindIntervalo = "
		SELECT P.CDPRODUTO, PC.CDCUPOMDESCFOS, P.NRORG
              FROM PRODCUPOMDESC PC JOIN PRODUTO P ON PC.CDPRODUTO = P.CDPRODUTO AND PC.NRORG = P.NRORG
            WHERE PC.CDCUPOMDESCFOS = :CDCUPOMDESCFOS AND PC.NRORG = :NRORG AND  P.CDARVPROD BETWEEN :CDARVPRODI AND :CDARVPRODF ORDER BY P.CDARVPROD
	";
}








